.. py:function:: coerce_double(x [, ret])

    Wrapper for :c:func:`gsl_coerce_double`
    c code signature: double gsl_coerce_double(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: expm1(x [, ret])

    Wrapper for :c:func:`gsl_expm1`
    c code signature: double gsl_expm1(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

.. py:function:: fcmp(x1, x2, epsilon [, ret])

    Wrapper for :c:func:`gsl_fcmp`
    c code signature: int gsl_fcmp(const double x1, const double x2, const double epsilon)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d__Rl__O`
    
    :param double x1: positional argument 0
    :param double x2: positional argument 1
    :param double epsilon: positional argument 2
    :param int ret: positional argument 3
    :rtype:  int 
    :return: result 

.. py:function:: fdiv(x, y [, ret])

    Wrapper for :c:func:`gsl_fdiv`
    c code signature: double gsl_fdiv(const double x, const double y)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: finite(x [, ret])

    Wrapper for :c:func:`gsl_finite`
    c code signature: int gsl_finite(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__O`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :rtype:  int 
    :return: result 

.. py:function:: frexp(x [, ret, e])

    Wrapper for :c:func:`gsl_frexp`
    c code signature: double gsl_frexp(const double x, int* e)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__Ol`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :param int e: positional argument 2
    :rtype:  tuple(:param double ret: positional argument 1, :param int e: positional argument 2) 
    :return: result 

.. py:function:: hypot(x, y [, ret])

    Wrapper for :c:func:`gsl_hypot`
    c code signature: double gsl_hypot(const double x, const double y)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d__Rd__O`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: hypot3(x, y, z [, ret])

    Wrapper for :c:func:`gsl_hypot3`
    c code signature: double gsl_hypot3(const double x, const double y, const double z)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_d_d__Rd__O`
    
    :param double x: positional argument 0
    :param double y: positional argument 1
    :param double z: positional argument 2
    :param double ret: positional argument 3
    :rtype:  double 
    :return: result 

.. py:function:: isinf(x [, ret])

    Wrapper for :c:func:`gsl_isinf`
    c code signature: int gsl_isinf(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__O`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :rtype:  int 
    :return: result 

.. py:function:: isnan(x [, ret])

    Wrapper for :c:func:`gsl_isnan`
    c code signature: int gsl_isnan(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rl__O`
    
    :param double x: positional argument 0
    :param int ret: positional argument 1
    :rtype:  int 
    :return: result 

.. py:function:: ldexp(x, e [, ret])

    Wrapper for :c:func:`gsl_ldexp`
    c code signature: double gsl_ldexp(const double x, const int e)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id_l__Rd__O`
    
    :param double x: positional argument 0
    :param int e: positional argument 1
    :param double ret: positional argument 2
    :rtype:  double 
    :return: result 

.. py:function:: log1p(x [, ret])

    Wrapper for :c:func:`gsl_log1p`
    c code signature: double gsl_log1p(const double x)
    Wrapped by ufunc :class:`PyGSL_sf_ufunc_Id__Rd__O`
    
    :param double x: positional argument 0
    :param double ret: positional argument 1
    :rtype:  double 
    :return: result 

